simplify.Customer

Package simplify :: Class Customer |
[hide private]
[frames] | no frames]

# Class Customer

source code

    domain.Domain --+
                    |
                   Customer

A Customer object.

Instance Methods | [hide private]
delete(self, *auth_args) Delete this object | source code
update(self, *auth_args) Updates this object | source code
Inherited from `domain.Domain`: `__getitem__`, `__init__`, `__setitem__`, `__str__`, `class_name`, `to_dict`

Static Methods | [hide private]
create(params, *auth_args) Creates an Customer object | source code
list(criteria=None, *auth_args) Retrieve Customer objects. | source code
find(object_id, *auth_args) Retrieve a Customer object from the API | source code

Method Details | [hide private]

### create(params, *auth_args) Static Method | source code
Creates an Customer object Parameters: `params` - a dict of parameters; valid keys are: `card => addressCity`: City of the cardholder. required `card => addressCountry`: Country code (ISO-3166-1-alpha-2 code) of residence of the cardholder. required `card => addressLine1`: Address of the cardholder required `card => addressLine2`: Address of the cardholder if needed. required `card => addressState`: State of residence of the cardholder. State abbreviations should be used. required `card => addressZip`: Postal code of the cardholder. The postal code size is between 5 and 9 in length and only contain numbers or letters. required `card => cvc`: CVC security code of the card. This is the code on the back of the card. Example: 123 required `card => expMonth`: Expiration month of the card. Format is MM. Example: January = 01 required `card => expYear`: Expiration year of the card. Format is YY. Example: 2013 = 13 required `card => id`: ID of card. Unused during customer create. `card => name`: Name as appears on the card. required `card => number`: Card number as it appears on the card. [max length: 19, min length: 13] `email`: Email address of the customer required `name`: Customer name [max length: 50, min length: 2] required `reference`: Reference field for external applications use. `subscriptions => amount`: Amount of payment in the smallest unit of your currency. Example: 100 = $1.00 `subscriptions => billingCycle`: How the plan is billed to the customer. Values must be AUTO (indefinitely until the customer cancels) or FIXED (a fixed number of billing cycles). [default: AUTO] `subscriptions => billingCycleLimit`: The number of fixed billing cycles for a plan. Only used if the billingCycle parameter is set to FIXED. Example: 4 `subscriptions => coupon`: Coupon associated with the subscription for the customer. `subscriptions => currency`: Currency code (ISO-4217). Must match the currency associated with your account. `subscriptions => currentPeriodEnd`: End date of subscription's current period `subscriptions => currentPeriodStart`: Start date of subscription's current period `subscriptions => customer`: The customer ID to create the subscription for. Do not supply this when creating a customer. `subscriptions => frequency`: Frequency of payment for the plan. Used in conjunction with frequencyPeriod. Valid values are "DAILY", "WEEKLY", "MONTHLY" and "YEARLY". `subscriptions => frequencyPeriod`: Period of frequency of payment for the plan. Example: if the frequency is weekly, and periodFrequency is 2, then the subscription is billed bi-weekly. `subscriptions => name`: Name describing subscription [max length: 50] `subscriptions => plan`: The plan ID that the subscription should be created from. `subscriptions => quantity`: Quantity of the plan for the subscription. [min value: 1] `subscriptions => renewalReminderLeadDays`: If set, how many days before the next billing cycle that a renewal reminder is sent to the customer. If null, then no emails are sent. Minimum value is 7 if set. `subscriptions => source`: Source of where subscription was created `token`: If specified, card associated with card token will be used `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. `private_api_key` - Private key to use for the API call. If `None`, the value of `simplify.private_key` will be used. Returns: a Customer object

### delete(self, *auth_args) | source code
Delete this object Parameters: `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object.

### list(criteria=None, *auth_args) Static Method | source code
Retrieve Customer objects. Parameters: `criteria` - a dict of parameters; valid keys are: `filter` <table class="filter_list"><tr><td>filter.id</td><td>Filter by the customer Id</td></tr><tr><td>filter.text</td><td>Can use this to filter by the name, email or reference for the customer</td></tr><tr><td>filter.dateCreatedMin<sup>*</sup></td><td>Filter by the minimum created date you are searching for - Date in UTC millis</td></tr><tr><td>filter.dateCreatedMax<sup>*</sup></td><td>Filter by the maximum created date you are searching for - Date in UTC millis</td></tr></table><br><sup>*</sup>Use dateCreatedMin with dateCreatedMax in the same filter if you want to search between two created dates `max` Allows up to a max of 50 list items to return. [min value: 0, max value: 50, default: 20] `offset` Used in paging of the list. This is the start offset of the page. [min value: 0, default: 0] `sorting` Allows for ascending or descending sorting of the list. The value maps properties to the sort direction (either `asc` for ascending or `desc` for descending). Sortable properties are: `dateCreated` `id` `name` `email` `reference`. `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. Returns: an object which contains the list of Customer objects in the <code>list</code> property and the total number of objects available for the given criteria in the <code>total</code> property.

### find(object_id, *auth_args) Static Method | source code
Retrieve a Customer object from the API Parameters: `object_id` - ID of object to retrieve `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. Returns: a Customer object

### update(self, *auth_args) | source code
Updates this object The properties that can be updated: `card => addressCity` City of the cardholder. (required) `card => addressCountry` Country code (ISO-3166-1-alpha-2 code) of residence of the cardholder. (required) `card => addressLine1` Address of the cardholder. (required) `card => addressLine2` Address of the cardholder if needed. (required) `card => addressState` State of residence of the cardholder. State abbreviations should be used. (required) `card => addressZip` Postal code of the cardholder. The postal code size is between 5 and 9 in length and only contain numbers or letters. (required) `card => cvc` CVC security code of the card. This is the code on the back of the card. Example: 123 (required) `card => expMonth` Expiration month of the card. Format is MM. Example: January = 01 (required) `card => expYear` Expiration year of the card. Format is YY. Example: 2013 = 13 (required) `card => id` ID of card. If present, card details for the customer will not be updated. If not present, the customer will be updated with the supplied card details. `card => name` Name as appears on the card. (required) `card => number` Card number as it appears on the card. [max length: 19, min length: 13] `email` Email address of the customer (required) `name` Customer name [max length: 50, min length: 2] (required) `reference` Reference field for external applications use. `token` If specified, card associated with card token will be added to the customer Parameters: `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. Returns: a Customer object.